@@ -10,7 +10,7 @@ from django.db.models import Avg
 import logging
 from django.conf import settings
 
-logger = logging.getLogger("thermostat")
+logger = logging.getLogger("thermostat.models")
 logger.setLevel(settings.LOG_LEVEL)
 
 
@@ -90,6 +90,8 @@ class TimeRange(models.Model):
 
 
 TEMP_CHOICES = (
+    ("luz_pasillo_off", "Apagar luz del pasillo"),
+    ("luz_pasillo_on", "Encender luz del pasillo"),
     ("tune_to_confort", "Confort"),
     ("tune_to_economic", "Economic"),
 
