@@ -5,7 +5,7 @@ from django_thermostat.models import Rule
 import logging
 from django.conf import settings
 
-logger = logging.getLogger("thermostat")
+logger = logging.getLogger("thermostat.rules")
 logger.setLevel(settings.LOG_LEVEL)
 
 
