@@ -1,27 +1,32 @@
 
 
 PASILLO_DID = "A1"
-CUARTO_OESTE_DID = "A2"
+CUARTO_ESTE_DID = "A2"
+CUARTO_OESTE_DID = "A4"
 SALON_DID = "A5"
 HEATER_DID = "C1"
 HEATER_PROTOCOL = "X10"
-HEATER_API = "http://raspberry:8000"
+HEATER_API = "http://localhost"
 
-HEATER_USERNAME = "username"
-HEATER_PASSWORD = "password"
+HEATER_USERNAME = "raton"
+HEATER_PASSWORD = "xxxx"
 HEATER_MARGIN = 0.0
 HEATER_INCREMENT = 0.5
 
-MINUTES_AFTER_SUNRISE_FOR_DAY = 0
-MINUTES_AFTER_SUNSET_FOR_DAY = 0
+
+AWS_CREDS_PATH = "/etc/aws.keys"
+AWS_ZONE = "us-east-1"
+
+MINUTES_AFTER_SUNRISE_FOR_DAY = 60
+MINUTES_AFTER_SUNSET_FOR_DAY = 60
 
 #INTERNAL_TEMPERATURE_URI = "http://raspberry/therm/temperature"
 #INTERNAL_TEMPERATURE_URI = "http://localhost:8000/therm/temperature"
 
-LIST_THERMOMETERS_API = "http://raspberry/thermometer/thermometers?"
+LIST_THERMOMETERS_API = "http://172.27.225.2/thermometer/thermometers?"
 #TEMPERATURES_API = "http://raspberry/therm/temperature_api/thermometers"
 #THERMOMETER_API = "http://raspberry/therm/temperature_api/thermometer/"
 
 FLAME_STATS = True
 FLAME_STATS_PATH = "./flame_stats.log"
-FLAME_STATS_DATE_FORMAT = "%d.%m.%Y %H:%M:%S"
\ No newline at end of file
+FLAME_STATS_DATE_FORMAT = "%d.%m.%Y %H:%M:%S"
